/*
  SF30 Serial Demo V1.0 
  Author: Zakia Ben Youss
  Copyright (c) 2015 Parallax Inc.
  See end of file for terms of use.


 This demo uses the serial input on the SF30 Laser Rangefinder to initiate a new range value to be sent serially to the Propeller. 
 Detects distance and displays it in meters on SimpleIDE Terminal or Parallax Serial Terminal (PST).

This test code applies for all SF30 High Speed Laser RangeFinder

NOTE:
-This demo assumes that the SF30 is set to a UART speed of 38400 Baud.
-This demo assumes that the SF30 is set to a 0.03m Snapshot Resolution. 
-This demo assumes that the SF30 is set to a 1144/sec Serial Port Update Rate.

See the product manual and instructions for details on changing the settings

You can find the manual by going to www.parallax.com and searching for SF30, and click Downloads & Documentation on the product page.

Wiring Diagram:

Pin_GND (Black)  On SF30 Laser Rangefinder - GND (Vss On Some Boards)
Pin_+5V (Red)    On SF30 Laser Rangefinder - +5V (Vdd On Some Boards)
Pin_TXD (Yellow) On SF30 Laser Rangefinder - Propeller RX Pin (0)
Pin_RXD (Orange) On SF30 Laser Rangefinder - Propeller TX Pin (1)

NOTE: 
Out of range distances will report 255 value.

  
  http://learn.parallax.com/propeller-c-simple-devices/
*/

#include "simpletools.h"
#include "fdserial.h"                             

int Byte_L,Byte_H;
int idx;
float distance;

int main()
{
  fdserial* sf30 = fdserial_open(0, 1, 0, 38400);  
  
  while(1)
  { 
    fdserial_rxReady(sf30);                
    if (fdserial_rxReady(sf30) != 0)                               // Check if Byte is ready in buffer & if ready..
    {
     idx++;
     Byte_L = fdserial_rxChar(sf30);                               // Receive low Byte
     Byte_H = fdserial_rxChar(sf30);                               // Receive high Byte
     distance = Byte_H * 256 + Byte_L;
     distance = distance/256;
     fdserial_rxReady(sf30);  
     if (idx%20 == 0) printf("distance = %2.2f m\n", distance);     // When counter reaches 10, print the distance
     pause(10);                                                    // Pause .1 s
     fdserial_rxReady(sf30);              
   }  
  }   
}

/*
  TERMS OF USE: MIT License
 
 Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation    
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,    
modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
is furnished to do so, subject to the following conditions:                                                                   
                                                                                                                              
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
                                                                                                                              
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE          
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR         
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,   
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.     
*/